@@ -32,6 +32,7 @@ extern "C" {
 #include "../../../config.h"
 #endif
 
+#include <retro_miscellaneous.h>
 #include <string/stdstring.h>
 
 #include "../../../configuration.h"
@@ -54,7 +55,7 @@ static inline void add_sublabel_and_whats_this(
 
    cbs.enum_idx = setting->enum_idx;
 
-   menu_cbs_init_bind_sublabel(&cbs, 0, 0, setting->type, setting->size);
+   menu_cbs_init_bind_sublabel(&cbs, NULL, NULL, 0, setting->type, setting->size);
 
    cbs.action_sublabel(0, 0, 0, 0, 0, tmp, sizeof(tmp));
 
@@ -289,11 +290,6 @@ CheckBox::CheckBox(rarch_setting_t *setting, QWidget *parent) :
    add_sublabel_and_whats_this(this, m_setting);
 }
 
-CheckBox::CheckBox(const char *setting, QWidget *parent) :
-   CheckBox(menu_setting_find(setting), parent)
-{
-}
-
 CheckBox::CheckBox(msg_hash_enums enum_idx, QWidget *parent) :
    CheckBox(menu_setting_find_enum(enum_idx), parent)
 {
@@ -339,11 +335,6 @@ CheckableSettingsGroup::CheckableSettingsGroup(rarch_setting_t *setting, QWidget
    }
 }
 
-CheckableSettingsGroup::CheckableSettingsGroup(const char *setting, QWidget *parent) :
-   CheckableSettingsGroup(menu_setting_find(setting), parent)
-{
-}
-
 CheckableSettingsGroup::CheckableSettingsGroup(msg_hash_enums enum_idx, QWidget *parent) :
    CheckableSettingsGroup(menu_setting_find_enum(enum_idx), parent)
 {
@@ -370,11 +361,6 @@ void CheckableSettingsGroup::paintEvent(QPaintEvent *event)
    QGroupBox::paintEvent(event);
 }
 
-CheckableIcon::CheckableIcon(const char *setting, const QIcon &icon, QWidget *parent) :
-   CheckableIcon(menu_setting_find(setting), icon, parent)
-{
-}
-
 CheckableIcon::CheckableIcon(msg_hash_enums enum_idx, const QIcon &icon, QWidget *parent) :
    CheckableIcon(menu_setting_find_enum(enum_idx), icon, parent)
 {
@@ -428,11 +414,6 @@ StringLineEdit::StringLineEdit(rarch_setting_t *setting, QWidget *parent) :
    add_sublabel_and_whats_this(this, m_setting);
 }
 
-StringLineEdit::StringLineEdit(const char *setting, QWidget *parent) :
-   StringLineEdit(menu_setting_find(setting), parent)
-{
-}
-
 void StringLineEdit::onEditingFinished()
 {
    strlcpy(m_value, text().toUtf8().data(), m_setting->size);
@@ -471,14 +452,9 @@ StringComboBox::StringComboBox(rarch_setting_t *setting, QWidget *parent) :
    add_sublabel_and_whats_this(this, m_setting);
 }
 
-StringComboBox::StringComboBox(const char *setting, QWidget *parent) :
-   StringComboBox(menu_setting_find(setting), parent)
-{
-}
-
 void StringComboBox::onCurrentTextChanged(const QString &text)
 {
-   strlcpy(m_value, text.toUtf8().data(), sizeof(m_value));
+   strlcpy(m_value, text.toUtf8().data(), m_setting->size);
 
    setting_generic_handle_change(m_setting);
 }
@@ -528,7 +504,7 @@ void UIntComboBox::populate(double min, double max)
    {
       for (i = min; i <= max; i += step)
       {
-         char val_s[256];
+         char val_s[NAME_MAX_LENGTH];
          unsigned val = (unsigned)i;
 
          *m_setting->value.target.unsigned_integer = val;
@@ -561,11 +537,6 @@ UIntComboBox::UIntComboBox(msg_hash_enums enum_idx, double min, double max, QWid
 {
 }
 
-UIntComboBox::UIntComboBox(const char *setting, QWidget *parent) :
-   UIntComboBox(menu_setting_find(setting), parent)
-{
-}
-
 void UIntComboBox::onCurrentIndexChanged(int index)
 {
    Q_UNUSED(index);
@@ -670,7 +641,7 @@ UIntRadioButton::UIntRadioButton(msg_hash_enums enum_idx, unsigned value, QWidge
    ,m_target(m_setting->value.target.unsigned_integer)
    ,m_value(value)
 {
-   char val_s[256];
+   char val_s[NAME_MAX_LENGTH];
    unsigned orig_value = *m_setting->value.target.unsigned_integer;
 
    *m_setting->value.target.unsigned_integer = value;
@@ -731,7 +702,7 @@ UIntRadioButtons::UIntRadioButtons(rarch_setting_t *setting, QWidget *parent) :
    {
       for (i = min; i <= max; i += step)
       {
-         char val_s[256];
+         char val_s[NAME_MAX_LENGTH];
 
          *setting->value.target.unsigned_integer = i;
 
@@ -753,12 +724,11 @@ UIntRadioButtons::UIntRadioButtons(rarch_setting_t *setting, QWidget *parent) :
       *setting->value.target.unsigned_integer = orig_value;
    }
    add_sublabel_and_whats_this(this, m_setting);
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+   connect(m_buttonGroup, &QButtonGroup::idClicked, this, &UIntRadioButtons::onButtonClicked);
+#else
    connect(m_buttonGroup, SIGNAL(buttonClicked(int)), this, SLOT(onButtonClicked(int)));
-}
-
-UIntRadioButtons::UIntRadioButtons(const char *setting, QWidget *parent) :
-   UIntRadioButtons(menu_setting_find(setting), parent)
-{
+#endif
 }
 
 UIntRadioButtons::UIntRadioButtons(msg_hash_enums enum_idx, QWidget *parent) :
@@ -806,11 +776,6 @@ void IntSpinBox::paintEvent(QPaintEvent *event)
    QSpinBox::paintEvent(event);
 }
 
-FloatSpinBox::FloatSpinBox(const char *setting, QWidget *parent) :
-   FloatSpinBox(menu_setting_find(setting), parent)
-{
-}
-
 FloatSpinBox::FloatSpinBox(msg_hash_enums enum_idx, QWidget *parent) :
     FloatSpinBox(menu_setting_find_enum(enum_idx), parent)
 {
@@ -874,11 +839,6 @@ PathButton::PathButton(rarch_setting_t *setting, QWidget *parent) :
    add_sublabel_and_whats_this(this, m_setting);
 }
 
-PathButton::PathButton(const char *setting, QWidget *parent) :
-   PathButton(menu_setting_find(setting), parent)
-{
-}
-
 QString PathButton::currentPath()
 {
    QString current(m_setting->value.target.string);
@@ -933,11 +893,6 @@ DirectorySelector::DirectorySelector(rarch_setting_t *setting, QWidget *parent)
    connect(m_button, SIGNAL(changed()), m_lineEdit, SLOT(update()));
 }
 
-FileSelector::FileSelector(const char *setting, QWidget *parent) :
-   FileSelector(menu_setting_find(setting), parent)
-{
-}
-
 FileSelector::FileSelector(rarch_setting_t *setting, QWidget *parent) :
    QHBoxLayout(parent)
    ,m_lineEdit(new StringLineEdit(setting))
@@ -950,11 +905,6 @@ FileSelector::FileSelector(rarch_setting_t *setting, QWidget *parent) :
    connect(m_button, SIGNAL(changed()), m_lineEdit, SLOT(update()));
 }
 
-FloatSlider::FloatSlider(const char *setting, QWidget *parent) :
-   FloatSlider(menu_setting_find(setting), parent)
-{
-}
-
 FloatSlider::FloatSlider(rarch_setting_t *setting, QWidget *parent) :
    QSlider(Qt::Horizontal, parent)
    ,m_setting(setting)
@@ -1003,11 +953,6 @@ void FloatSlider::paintEvent(QPaintEvent *event)
    QSlider::paintEvent(event);
 }
 
-FloatSliderAndSpinBox::FloatSliderAndSpinBox(const char *setting, QWidget *parent) :
-   FloatSliderAndSpinBox(menu_setting_find(setting), parent)
-{
-}
-
 FloatSliderAndSpinBox::FloatSliderAndSpinBox(msg_hash_enums enum_idx, QWidget *parent) :
    FloatSliderAndSpinBox(menu_setting_find_enum(enum_idx), parent)
 {
@@ -1043,7 +988,7 @@ BindButton::BindButton(rarch_setting_t *setting, QWidget *parent) :
    QPushButton(parent)
    ,m_setting(setting)
 {
-   char val_s[256];
+   char val_s[NAME_MAX_LENGTH];
 
    setting->get_string_representation(setting, val_s, sizeof(val_s));
 
@@ -1299,6 +1244,7 @@ void MainWindow::onFileDropWidgetContextMenuRequested(const QPoint &pos)
                m_pendingThumbnailDownloadTypes.append(THUMBNAIL_BOXART);
                m_pendingThumbnailDownloadTypes.append(THUMBNAIL_SCREENSHOT);
                m_pendingThumbnailDownloadTypes.append(THUMBNAIL_TITLE);
+               m_pendingThumbnailDownloadTypes.append(THUMBNAIL_LOGO);
                downloadThumbnail(system, title);
             }
             else
